@@ -174,7 +174,8 @@ public:
 
     ~CatalogueWriter() override {}
 
-    virtual const Index& currentIndex() = 0;
+    virtual bool createIndex(const Key& idxKey, size_t datumKeySize) = 0;
+    virtual const Index& currentIndex()                              = 0;
     virtual const Key currentIndexKey();
     virtual void archive(const Key& idxKey, const Key& datumKey,
                          std::shared_ptr<const FieldLocation> fieldLocation)                              = 0;
@@ -301,7 +302,6 @@ public:
     const Schema& schema() const override { NOTIMP; }
     const Rule& rule() const override { NOTIMP; }
 
-    bool selectIndex(const Key& idxKey) override { NOTIMP; }
     void deselectIndex() override { NOTIMP; }
 
     std::vector<eckit::PathName> metadataPaths() const override { NOTIMP; }
