@@ -14,7 +14,10 @@ using namespace eckit;
 
 namespace fdb5 {
 
-::eckit::ClassSpec IndexLocation::classSpec_ = {&Streamable::classSpec(), "IndexLocation",};
+::eckit::ClassSpec IndexLocation::classSpec_ = {
+    &Streamable::classSpec(),
+    "IndexLocation",
+};
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -22,8 +25,8 @@ IndexLocation::IndexLocation() {}
 
 IndexLocationVisitor::~IndexLocationVisitor() {}
 
-IndexLocation::~IndexLocation(){}
+IndexLocation::~IndexLocation() {}
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}
+}  // namespace fdb5
