@@ -15,7 +15,7 @@
 #ifndef fdb5_RadosStore_H
 #define fdb5_RadosStore_H
 
-#include "fdb5/database/DB.h"
+#include "fdb5/database/Catalogue.h"
 #include "fdb5/database/Index.h"
 #include "fdb5/database/Store.h"
 #include "fdb5/rules/Schema.h"
@@ -28,7 +28,7 @@ namespace fdb5 {
 
 class RadosStore : public Store {
 
-public: // methods
+public:  // methods
 
     RadosStore(const Schema& schema, const Key& key, const Config& config);
 
@@ -37,51 +37,52 @@ public: // methods
     eckit::URI uri() const override;
 
     bool open() override { return true; }
-    void flush() override;
+    size_t flush() override;
     void close() override;
 
     void checkUID() const override { /* nothing to do */ }
 
-protected: // methods
+protected:  // methods
 
     std::string type() const override { return "rados"; }
 
     bool exists() const override;
 
     eckit::DataHandle* retrieve(Field& field, Key& remapKey) const override;
-    FieldLocation* archive(const Key &key, const void *data, eckit::Length length) override;
+    std::unique_ptr<const FieldLocation> archive(const uint32_t, const Key& key, const void* data,
+                                                 eckit::Length length) override;
 
     void remove(const eckit::URI& uri, std::ostream& logAlways, std::ostream& logVerbose, bool doit) const override;
 
-    eckit::DataHandle *getCachedHandle( const eckit::PathName &path ) const;
+    eckit::DataHandle* getCachedHandle(const eckit::PathName& path) const;
     void closeDataHandles();
-    eckit::DataHandle *createFileHandle(const eckit::PathName &path);
-    eckit::DataHandle *createAsyncHandle(const eckit::PathName &path);
-    eckit::DataHandle *createDataHandle(const eckit::PathName &path);
-    eckit::DataHandle& getDataHandle( const eckit::PathName &path );
-    eckit::PathName generateDataPath(const Key &key) const;
-    eckit::PathName getDataPath(const Key &key);
+    eckit::DataHandle* createFileHandle(const eckit::PathName& path);
+    eckit::DataHandle* createAsyncHandle(const eckit::PathName& path);
+    eckit::DataHandle* createDataHandle(const eckit::PathName& path);
+    eckit::DataHandle& getDataHandle(const eckit::PathName& path);
+    eckit::PathName generateDataPath(const Key& key) const;
+    eckit::PathName getDataPath(const Key& key);
     void flushDataHandles();
 
-    void print( std::ostream &out ) const override;
+    void print(std::ostream& out) const override;
 
-private: // types
+private:  // types
 
-    typedef std::map< std::string, eckit::DataHandle * >  HandleStore;
-    typedef std::map< Key, std::string > PathStore;
+    typedef std::map<std::string, eckit::DataHandle*> HandleStore;
+    typedef std::map<Key, std::string> PathStore;
 
-private: // members
+private:  // members
 
-    HandleStore handles_;    ///< stores the DataHandles being used by the Session
+    HandleStore handles_;  ///< stores the DataHandles being used by the Session
 
-    PathStore   dataPaths_;
+    PathStore dataPaths_;
     eckit::PathName directory_;
 
-    mutable bool dirty_;
+    size_t archivedFields_;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
-#endif //fdb5_RadosStore_H
+#endif  // fdb5_RadosStore_H
