@@ -12,6 +12,7 @@
 #include "eckit/option/SimpleOption.h"
 
 #include "fdb5/LibFdb5.h"
+#include "fdb5/api/helpers/FDBToolRequest.h"
 #include "fdb5/tools/FDBTool.h"
 
 namespace fdb5 {
@@ -67,6 +68,16 @@ Config FDBTool::config(const eckit::option::CmdArgs& args, const eckit::Configur
     return LibFdb5::instance().defaultConfig(userConfig);
 }
 
+std::vector<Key> FDBTool::parse(const std::string& request, const fdb5::Config& config) {
+    auto dbrequests = FDBToolRequest::requestsFromString(request, {}, false, "read");
+    ASSERT(dbrequests.size() == 1);
+
+    const auto& dbrequest = dbrequests.front();
+    ASSERT(!dbrequest.all());
+
+    return config.schema().expandDatabase(dbrequest.request());
+}
+
 void FDBTool::usage(const std::string&) const {}
 
 void FDBTool::init(const eckit::option::CmdArgs&) {}
