@@ -26,21 +26,19 @@ namespace tools {
 //----------------------------------------------------------------------------------------------------------------------
 
 class FDBWhere : public FDBVisitTool {
-  public: // methods
+public:  // methods
 
-    FDBWhere(int argc, char **argv) :
-        FDBVisitTool(argc, argv, "class,expver"),
-        porcelain_(false) {
+    FDBWhere(int argc, char** argv) : FDBVisitTool(argc, argv, "class,expver"), porcelain_(false) {
 
         options_.push_back(new SimpleOption<bool>("porcelain", "Streamlined output for input into other tools"));
     }
 
-  private: // methods
+private:  // methods
 
     void execute(const CmdArgs& args) override;
-    void init(const CmdArgs &args) override;
+    void init(const CmdArgs& args) override;
 
-  private: // members
+private:  // members
 
     bool porcelain_;
 };
@@ -77,11 +75,11 @@ void FDBWhere::execute(const CmdArgs& args) {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace tools
-} // namespace fdb5
+}  // namespace tools
+}  // namespace fdb5
 
 
-int main(int argc, char **argv) {
+int main(int argc, char** argv) {
     fdb5::tools::FDBWhere app(argc, argv);
     return app.start();
 }
