@@ -24,26 +24,22 @@ namespace fdb5 {
 
 class TypeInteger : public Type {
 
-public: // methods
+public:  // methods
 
-    TypeInteger(const std::string &name, const std::string &type);
+    TypeInteger(const std::string& name, const std::string& type);
 
     ~TypeInteger() override;
 
-    virtual void getValues(const metkit::mars::MarsRequest &request,
-                           const std::string &keyword,
-                           eckit::StringList &values,
-                           const Notifier &wind,
-                           const CatalogueReader* cat) const override;
+    virtual void getValues(const metkit::mars::MarsRequest& request, const std::string& keyword,
+                           eckit::StringList& values, const Notifier& wind, const CatalogueReader* cat) const override;
 
-private: // methods
-
-    void print( std::ostream &out ) const override;
+private:  // methods
 
+    void print(std::ostream& out) const override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
 #endif
