@@ -1,9 +1,9 @@
-#include "eckit/testing/Test.h"
-#include "eckit/filesystem/TmpDir.h"
 #include "eckit/filesystem/LocalPathName.h"
-#include "metkit/mars/MarsRequest.h"
+#include "eckit/filesystem/TmpDir.h"
+#include "eckit/testing/Test.h"
 #include "fdb5/api/FDB.h"
 #include "fdb5/api/helpers/FDBToolRequest.h"
+#include "metkit/mars/MarsRequest.h"
 
 namespace fdb5::test {
 
@@ -14,8 +14,8 @@ std::set<std::string> extensions = {"foo", "bar"};
 eckit::PathName writeAuxiliaryData(const eckit::PathName datapath, const std::string ext) {
     eckit::PathName auxpath(datapath + "." + ext);
     std::string data_str = "Some extra data";
-    const void* data = static_cast<const void *>(data_str.c_str());
-    size_t length = data_str.size();
+    const void* data     = static_cast<const void*>(data_str.c_str());
+    size_t length        = data_str.size();
     eckit::FileHandle file(auxpath);
     file.openForWrite(0);
     file.write(data, length);
@@ -26,7 +26,8 @@ eckit::PathName writeAuxiliaryData(const eckit::PathName datapath, const std::st
 std::set<eckit::PathName> setup(FDB& fdb) {
     // Setup: Write data, generating auxiliary files using the archive callback
     std::set<eckit::PathName> auxPaths;
-    fdb.registerArchiveCallback([&auxPaths] (const Key& key, const void* data, size_t length, std::future<std::shared_ptr<const FieldLocation>> future) {
+    fdb.registerArchiveCallback([&auxPaths](const Key& key, const void* data, size_t length,
+                                            std::future<std::shared_ptr<const FieldLocation>> future) {
         std::shared_ptr<const FieldLocation> location = future.get();
         for (const auto& ext : extensions) {
             auxPaths.insert(writeAuxiliaryData(location->uri().path(), ext));
@@ -34,29 +35,29 @@ std::set<eckit::PathName> setup(FDB& fdb) {
     });
 
     std::string data_str = "Raining cats and dogs";
-    const void* data = static_cast<const void *>(data_str.c_str());
-    size_t length = data_str.size();
+    const void* data     = static_cast<const void*>(data_str.c_str());
+    size_t length        = data_str.size();
 
     Key key;
-    key.set("class","od");
-    key.set("expver","xxxx");
-    key.set("type","fc");
-    key.set("stream","oper");
-    key.set("date","20101010");
-    key.set("time","0000");
-    key.set("domain","g");
-    key.set("levtype","sfc");
-    key.set("param","130");
+    key.set("class", "od");
+    key.set("expver", "xxxx");
+    key.set("type", "fc");
+    key.set("stream", "oper");
+    key.set("date", "20101010");
+    key.set("time", "0000");
+    key.set("domain", "g");
+    key.set("levtype", "sfc");
+    key.set("param", "130");
 
-    key.set("step","1");
+    key.set("step", "1");
     fdb.archive(key, data, length);
 
-    key.set("date","20111213");
+    key.set("date", "20111213");
     fdb.archive(key, data, length);
 
-    key.set("type","pf");
+    key.set("type", "pf");
     fdb.archive(key, data, length);
- 
+
     fdb.flush();
 
     return auxPaths;
@@ -75,11 +76,11 @@ CASE("Wipe with extensions") {
     for (const auto& auxPath : auxPaths) {
         EXPECT(auxPath.exists());
     }
-    
+
     // call wipe
     FDBToolRequest request = FDBToolRequest::requestsFromString("class=od,expver=xxxx")[0];
-    bool doit = true;
-    auto listObject = fdb.wipe(request, doit);
+    bool doit              = true;
+    auto listObject        = fdb.wipe(request, doit);
 
     WipeElement elem;
     while (listObject.next(elem)) {
@@ -120,12 +121,12 @@ CASE("Purge with extensions") {
 
     // call purge
     FDBToolRequest request = FDBToolRequest::requestsFromString("class=od,expver=xxxx")[0];
-    bool doit = true;
-    auto listObject = fdb.purge(request, doit, false);
+    bool doit              = true;
+    auto listObject        = fdb.purge(request, doit, false);
 
     PurgeElement elem;
     while (listObject.next(elem)) {
-        eckit::Log::info () << elem << std::endl;
+        eckit::Log::info() << elem << std::endl;
     }
 
     // Check that the masked auxiliary files have been removed
@@ -141,7 +142,7 @@ CASE("Purge with extensions") {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5::test
+}  // namespace fdb5::test
 
 int main(int argc, char** argv) {
 
