@@ -1,6 +1,6 @@
-#include "eckit/testing/Test.h"
-#include "eckit/filesystem/TmpDir.h"
 #include "eckit/filesystem/LocalPathName.h"
+#include "eckit/filesystem/TmpDir.h"
+#include "eckit/testing/Test.h"
 #include "fdb5/api/FDB.h"
 
 namespace fdb5::test {
@@ -14,45 +14,44 @@ CASE("Archive and flush callback") {
     FDB fdb;
 
     std::string data_str = "Raining cats and dogs";
-    const void* data = static_cast<const void *>(data_str.c_str());
-    size_t length = data_str.size();
+    const void* data     = static_cast<const void*>(data_str.c_str());
+    size_t length        = data_str.size();
 
     Key key;
-    key.set("class","od");
-    key.set("expver","xxxx");
-    key.set("type","fc");
-    key.set("stream","oper");
-    key.set("date","20101010");
-    key.set("time","0000");
-    key.set("domain","g");
-    key.set("levtype","sfc");
-    key.set("param","130");
+    key.set("class", "od");
+    key.set("expver", "xxxx");
+    key.set("type", "fc");
+    key.set("stream", "oper");
+    key.set("date", "20101010");
+    key.set("time", "0000");
+    key.set("domain", "g");
+    key.set("levtype", "sfc");
+    key.set("param", "130");
 
     std::map<fdb5::Key, eckit::URI> map;
     std::vector<Key> keys;
     bool flushCalled = false;
 
-    fdb.registerArchiveCallback([&map] (const Key& key, const void* data, size_t length, std::future<std::shared_ptr<const FieldLocation>> future) {
+    fdb.registerArchiveCallback([&map](const Key& key, const void* data, size_t length,
+                                       std::future<std::shared_ptr<const FieldLocation>> future) {
         std::shared_ptr<const FieldLocation> location = future.get();
-        map[key] = location->fullUri();
+        map[key]                                      = location->fullUri();
     });
 
-    fdb.registerFlushCallback([&flushCalled] () {
-        flushCalled = true;
-    });
+    fdb.registerFlushCallback([&flushCalled]() { flushCalled = true; });
 
-    key.set("step","1");
+    key.set("step", "1");
     keys.push_back(key);
     fdb.archive(key, data, length);
 
-    key.set("date","20111213");
+    key.set("date", "20111213");
     keys.push_back(key);
     fdb.archive(key, data, length);
 
-    key.set("type","pf");
+    key.set("type", "pf");
     keys.push_back(key);
     fdb.archive(key, data, length);
-    
+
     fdb.flush();
 
     EXPECT(flushCalled);
@@ -62,18 +61,17 @@ CASE("Archive and flush callback") {
     for (const auto& [key, uri] : map) {
         bool found = false;
         for (const auto& originalKey : keys) {
-            if (key == originalKey){
+            if (key == originalKey) {
                 found = true;
                 break;
             }
         }
         EXPECT(found);
     }
-    
 }
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5::test
+}  // namespace fdb5::test
 
 int main(int argc, char** argv) {
 
